﻿Imports System.Runtime.CompilerServices
Imports Infragistics.UltraChart.Data
Imports Infragistics.Win.UltraWinChart.UltraChart
Imports Infragistics.UltraChart.Core.Primitives

Public Module Module1

  ''' <summary>
  ''' Returns whether or not the <see cref="Primitive">Primitive</see> is a <see cref="GanttTimeEntry">GanttTimeEntry</see>.
  ''' </summary>
  ''' <param name="primitive">The <see cref="Primitive">Primitive</see> being parsed.</param>
  ''' <returns><c>True</c> if the <see cref="Primitive">Primitive</see> a represents <see cref="GanttTimeEntry">GanttTimeEntry</see>;
  ''' otherwise <c>False</c>.</returns>
  <Extension()> _
  Public Function IsTimeEntry(ByVal primitive As Primitive) As Boolean
    Dim result As Boolean = False
    If TypeOf primitive Is Box Then
      If primitive.Tags IsNot Nothing Then
        result = primitive.Tags.ContainsKey(primitive.TimeEntryIndexKey)
      End If
    End If
    Return result
  End Function
  ''' <summary>
  ''' Returns the index of the <see cref="GanttTimeEntry">GanttTimeEntry</see> represented by the <see cref="Primitive">Primitive</see>.
  ''' </summary>
  ''' <param name="primitive">The <see cref="Primitive">Primitive</see> being parsed.</param>
  ''' <returns>A value of zero or greater (>= 0) if a successful index is found; otherwise negative one (-1).</returns>
  <Extension()> _
  Public Function TimeEntryIndex(ByVal primitive As Primitive) As Integer
    Dim result As Integer = -1
    If primitive.IsTimeEntry Then
      result = CInt(primitive.Tags(primitive.TimeEntryIndexKey))
      'Dim ganttSeries As GanttSeries = primitive.Series
    End If
    Return result
  End Function
  ''' <summary>
  ''' Returns the <see cref="GanttTimeEntry">GanttTimeEntry</see> represented by the <see cref="Primitive">Primitive</see>.
  ''' </summary>
  ''' <param name="primitive">The <see cref="Primitive">Primitive</see> being parsed.</param>
  ''' <returns>A <see cref="GanttTimeEntry">GanttTimeEntry</see> if the passed <see cref="Primitive">Primitive</see> represents represents as such;
  ''' otherwise Nothing.</returns>
  <Extension()> _
  Public Function TimeEntry(ByVal primitive As Primitive) As GanttTimeEntry
    Dim result As GanttTimeEntry = Nothing
    If primitive.IsTimeEntry Then
      Dim ganttItem As GanttItem = CType(primitive.DataPoint, GanttItem)
      result = ganttItem.Times(primitive.TimeEntryIndex)
    End If
    Return result
  End Function

  ''' <summary>
  ''' The <see cref="String">String</see> to use to reference an element within the <see cref="Hashtable">Hashtable</see> of 
  ''' a <see cref="Primitive">Primitive</see> to get the <see cref="GanttTimeEntry">GanttTimeEntry</see> Index; i.e. "TIME_ENTRY_INDEX".
  ''' </summary>
  ''' <param name="primitive"></param>
  ''' <returns>"TIME_ENTRY_INDEX"</returns>
  <Extension()> _
  Public Function TimeEntryIndexKey(ByVal primitive As Primitive) As String
    Return "TIME_ENTRY_INDEX"
  End Function
End Module
